Django Dynamic REST
===================

**Dynamic API extensions for Django REST Framework**

See http://dynamic-rest.readthedocs.org for full documentation.

Overview
========

Django Dynamic REST (or DDREST) extends the popular `Django REST
Framework <https://django-rest-framework.org>`__ (or DRF) with API
features that empower simple RESTful APIs with the flexibility of a
graph query language.

DDREST classes can be used as a drop-in replacement for DRF classes,
which offer the following features on top of the standard DRF kit:

-  Linked relationships
-  Sideloaded relationships
-  Embedded relationships
-  Field inclusions
-  Field exclusions
-  Field-based filtering
-  Field-based sorting
-  Directory panel for your Browsable API
-  Optimizations

DDREST is the continuation of `dynamic-rest <https://github.com/AltSchool/dynamic-rest>`
written by `AltSchool <https://github.com/AltSchool` which meant to complement `Ember
Data <https://github.com/emberjs/data>`__, but it can be used to provide
fast and flexible CRUD operations to any consumer that supports JSON
over HTTP.

Maintainers
-----------

-  `Ernesto González <mailto:ernesto@hunchat.com>`__

Requirements
============

-  Python (3.6, 3.7, 3.8)
-  Django (2.0, 2.1, 2.2, 3.1, 3.2)
-  Django REST Framework (3.8, 3.9, 3.10, 3.11, 3.12)
